from .CatBoostRegressor import CatBoostRegressor
from .LGBMRegressor import LGBMRegressor
from .XGBRegressor import XGBRegressor
from .StackingRegressor import StackingRegressor
from .PartialBoostingRegressor import PartialBoostingRegressor
